%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function varargout = U20FrictionTool(varargin)
% U20FrictionTool M-file for U20FrictionTool.fig
%      U20FrictionTool, by itself, creates a new U20FrictionTool or raises the existing
%      singleton*.
%
%      H = U20FrictionTool returns the handle to a new U20FrictionTool or the handle to
%      the existing singleton*.
%
%      U20FrictionTool('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in U20FrictionTool.M with the given input arguments.
%
%      U20FrictionTool('Property','Value',...) creates a new U20FrictionTool or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before matrix_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to U20FrictionTool_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help U20FrictionTool

% Last Modified by GUIDE v2.5 15-Dec-2009 12:08:13

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @U20FrictionTool_OpeningFcn, ...
                   'gui_OutputFcn',  @U20FrictionTool_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before U20FrictionTool is made visible.
function U20FrictionTool_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to U20FrictionTool (see VARARGIN)

% Choose default command line output for U20FrictionTool
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes U20FrictionTool wait for user response (see UIRESUME)
% uiwait(handles.figure_main);
addpath([cd,'/code']);
addpath([cd,'/code/math']);
addpath([cd,'/databases']);
% clc

%initialise default data
Matrix.Name = 'default';
Matrix.Model= 'CrossWLF';
Matrix.n    = 0.3973;
Matrix.tau  = 10987.6;
Matrix.D1   = 1.33454e+014;
Matrix.D2   = 263.15;
Matrix.D3   = 0;
Matrix.A1   = 32.17;
Matrix.AT   = 51.6;
% const visc prop
Matrix.eta  = 250;

setappdata(handles.figure_main,'Matrix',Matrix);
set_uipanel_model(handles);
update_parameter_panel(handles);

gmin = -2;
gmax =  4;
T    = 200;
setappdata(handles.figure_main,'gmin',gmin);
setappdata(handles.figure_main,'gmax',gmax);
setappdata(handles.figure_main,'T',T);
edit_gmin_Callback(handles.edit_gmin, eventdata, handles);
edit_gmax_Callback(handles.edit_gmax, eventdata, handles);
edit_T_Callback(handles.edit_T, eventdata, handles);

%default data weaves
Weave.type = 'plain';
Weave.warpcount = 377.35;
Weave.weftcount = 168.35;
Weave.thickness = 1.0;
Weave.npoints   = 1000;
Weave.spacing   = 0;
setappdata(handles.figure_main,'Weave',Weave);
set_uipanel_weavegeo(handles);
popupmenu_weaveselect_Callback(handles.popupmenu_weaveselect, eventdata, handles);

%default data fricprop calculation
FricProp.T = 200;
FricProp.p = 42.11;
FricProp.vmin = 20/60;
FricProp.vmax = 500/60;
FricProp.n = 3;
FricProp.dir = 'top';
FricProp.use_lower_limit = true;
FricProp.use_upper_limit = false;
FricProp.lower_limit = 10;
FricProp.upper_limit = 25;

setappdata(handles.figure_main,'FricProp',FricProp);
set_uipanel_fricprop(handles);

%default export data
Exp2Workspace = [];
setappdata(handles.figure_main,'Exp2Workspace',Exp2Workspace);

% default size and put main window in middle of screen and resize main window
set(hObject,'Units','characters');
setappdata(handles.figure_main,'active_panel',1);
show_visible_panel(handles);
figure_main_ResizeFcn(hObject, eventdata, handles);
pos = get(hObject,'position');
scrsize = get(0,'ScreenSize');
pos(1) = (scrsize(3)-pos(3))/2;
pos(2) = (scrsize(4)-pos(4))/2;
set(hObject,'position',pos);

% --- Outputs from this function are returned to the command line.
function varargout = U20FrictionTool_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes when figure_main is resized.
function figure_main_ResizeFcn(hObject, eventdata, handles)
% hObject    handle to figure_main (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if isempty(handles)
    return;
end
set(hObject,'Units','characters');
position = get(hObject,'position');
min_x = 110;
min_y = 40;
if position(3)<min_x
    position(3)=min_x;
end    
if position(4)<min_y
    position(4)=min_y;
end
%move it when it is out of sight
set(0,'Units','characters');
scrsize = get(0,'ScreenSize');
if (position(1)+position(3))>scrsize(3)
    position(1) = scrsize(3)- position(3) -5;
end
if (position(2)+position(4))>scrsize(4)
    position(2) = scrsize(4)- position(4) -5;
end
set(hObject,'position',position);

h_border = 0.2;
h_tabs   = 21.5;
w_border = 0.5;
w_tab    = 40;

p = position;
pos_tabmatrix = [w_border p(4)-h_border-2.5 22 2.5];
set(handles.pushbutton_selectmatrixtab,'Position',pos_tabmatrix)
pos_tabweave = [pos_tabmatrix(1)+h_tabs p(4)-h_border-2.5 22 2.5];
set(handles.pushbutton_selectgeotab,'Position',pos_tabweave)
pos_tabfric = [pos_tabweave(1)+h_tabs p(4)-h_border-2.5 22 2.5];
set(handles.pushbutton_selectfrictiontab,'Position',pos_tabfric)

%h_panels = 30
p_panels = [0 0 p(3) p(4)-3.0];
set(handles.uipanel_matrix,'Position',p_panels);
set(handles.uipanel_weavegeo,'Position',p_panels);
set(handles.uipanel_fricprop,'Position',p_panels);

function edit_gmin_Callback(hObject, eventdata, handles)
% hObject    handle to edit_gmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_gmin as text
%        str2double(get(hObject,'String')) returns contents of edit_gmin as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    gmax = getappdata(handles.figure_main,'gmax');
    if nmbr < gmax
        setappdata(handles.figure_main,'gmin',nmbr);
    else
        errordlg('min. shear rate must be larger than max. shear rate')
    end
else
    errordlg('Cannot convert input to a numeric value')
end
gmin = getappdata(handles.figure_main,'gmin');
set(hObject,'String',num2str(gmin));

% --- Executes during object creation, after setting all properties.
function edit_gmin_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_gmin (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_gmax_Callback(hObject, eventdata, handles)
% hObject    handle to edit_gmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_gmax as text
%        str2double(get(hObject,'String')) returns contents of edit_gmax as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    gmin = getappdata(handles.figure_main,'gmin');
    if nmbr > gmin
        setappdata(handles.figure_main,'gmax',nmbr);
    else
        errordlg('max. shear rate must be larger than min. shear rate')
    end
else
    errordlg('Cannot convert input to a numeric value')
end
gmax = getappdata(handles.figure_main,'gmax');
set(hObject,'String',num2str(gmax));

% --- Executes during object creation, after setting all properties.
function edit_gmax_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_gmax (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_T_Callback(hObject, eventdata, handles)
% hObject    handle to edit_T (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_T as text
%        str2double(get(hObject,'String')) returns contents of edit_T as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    setappdata(handles.figure_main,'T',nmbr);
else
    errordlg('Cannot convert input to a numeric value')
end
T = getappdata(handles.figure_main,'T');
set(hObject,'String',num2str(T));

% --- Executes during object creation, after setting all properties.
function edit_T_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_T (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in pushbutton_plot.
function pushbutton_plot_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_plot (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

Matrix = getappdata(handles.figure_main,'Matrix');
T       = str2double(get(handles.edit_T,'String'));
gmin    = str2double(get(handles.edit_gmin,'String'));
gmax    = str2double(get(handles.edit_gmax,'String'));
gam_dot = logspace(gmin,gmax,500); 
eta     = give_eta(Matrix,T,gam_dot);
H = handles.axes_plot;
set(H,'XScale','log');
set(H,'YScale','log');
xlabel(H,'shear rate [1/s]');
ylabel(H,'viscosity [Pa s]');
hold(H,'on');

% determine linespecs
nplots = length(get(handles.axes_plot,'Children'))+1;
linespec = {'-' '--' ':' '-.'};
colspec  = {'k' 'r' 'b' 'g' 'c' 'm' 'y'};
ilspec = 1;
icspec = 1;
for i=1:nplots
    if ilspec>length(linespec)
        ilspec = 1;
        icspec = icspec + 1;
    end
    if icspec>length(colspec)
        icspec = 1;
    end
    spec = [colspec{icspec},linespec{ilspec}];
    ilspec = ilspec + 1;
end
loglog(H,gam_dot,eta,spec);
lHandle = legend(H);
Leg = get(lHandle,'String');
name = [Matrix.Name,', ',Matrix.Model];
Leg = [Leg, cellstr([name,'; T = ',num2str(T),' C'])];
legend(H,Leg,'FontSize',7);
hold on;

% --- Executes on button press in pushbutton_clearplot.
function pushbutton_clearplot_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_clearplot (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
button = questdlg('Clear graph?','Clear graph','last','all','cancel','cancel');
H = handles.axes_plot;
if strcmpi(button,'all')
    cla(H);
    legend(H,'off');
elseif strcmpi(button,'last')
    Hch = get(H,'Children');
    if ~isempty(Hch)
        Hlast = Hch(1);
        delete(Hlast);
        lHandle = legend(H);
        Leg = get(lHandle,'String');
        Leg = Leg(1:end-1);
        if ~isempty(Leg)
            legend(H,Leg,'FontSize',7);
        else
            legend(H,'off');
        end
    end
end

% --- Executes on selection change in popupmenu_database.
function popupmenu_database_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_database (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu_database contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu_database


% --- Executes on selection change in popupmenu_model.
function popupmenu_model_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_model (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu_model contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu_model
S = get(hObject,'String');
model = S{get(hObject,'Value')};
Matrix = getappdata(handles.figure_main,'Matrix');
if strcmpi(model,'Cross-WLF')
    Matrix.Model = 'CrossWLF';
elseif strcmpi(model,'constant viscosity')
    Matrix.Model='constant';
end
setappdata(handles.figure_main,'Matrix',Matrix);    
set_uipanel_model(handles);
update_parameter_panel(handles);

function set_uipanel_model(handles)
Matrix = getappdata(handles.figure_main,'Matrix');
set(handles.uipanel_constviscosity,'Visible','off');
set(handles.uipanel_CrossWLF,'Visible','off');    
if strcmpi(Matrix.Model,'CrossWLF')
    set(handles.uipanel_CrossWLF,'Visible','on'); 
    set(handles.popupmenu_model,'Value',1);
elseif strcmpi(Matrix.Model,'constant')
    set(handles.uipanel_constviscosity,'Visible','on'); 
    set(handles.popupmenu_model,'Value',2);
end

% --- Executes during object creation, after setting all properties.
function popupmenu_model_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_model (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_nCWLF_Callback(hObject, eventdata, handles)
% hObject    handle to edit_nCWLF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_nCWLF as text
%        str2double(get(hObject,'String')) returns contents of edit_nCWLF as a double


% --- Executes during object creation, after setting all properties.
function edit_nCWLF_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_nCWLF (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit_cvisc_eta_Callback(hObject, eventdata, handles)
% hObject    handle to edit_cvisc_eta (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_cvisc_eta as text
%        str2double(get(hObject,'String')) returns contents of edit_cvisc_eta as a double


% --- Executes during object creation, after setting all properties.
function edit_cvisc_eta_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_cvisc_eta (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit11_Callback(hObject, eventdata, handles)
% hObject    handle to edit11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit11 as text
%        str2double(get(hObject,'String')) returns contents of edit11 as a double


% --- Executes during object creation, after setting all properties.
function edit11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit12_Callback(hObject, eventdata, handles)
% hObject    handle to edit12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit12 as text
%        str2double(get(hObject,'String')) returns contents of edit12 as a double


% --- Executes during object creation, after setting all properties.
function edit12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit13_Callback(hObject, eventdata, handles)
% hObject    handle to edit13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit13 as text
%        str2double(get(hObject,'String')) returns contents of edit13 as a double


% --- Executes during object creation, after setting all properties.
function edit13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit14_Callback(hObject, eventdata, handles)
% hObject    handle to edit14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit14 as text
%        str2double(get(hObject,'String')) returns contents of edit14 as a double


% --- Executes during object creation, after setting all properties.
function edit14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit15_Callback(hObject, eventdata, handles)
% hObject    handle to edit15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit15 as text
%        str2double(get(hObject,'String')) returns contents of edit15 as a double


% --- Executes during object creation, after setting all properties.
function edit15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton_adj_par_model.
function pushbutton_adj_par_model_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_adj_par_model (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)\
popupmenu_model_Callback(handles.popupmenu_model, eventdata,handles);
Matrix = getappdata(handles.figure_main,'Matrix');
if strcmpi(Matrix.Model,'CrossWLF')
    names = {'n','tau','D1','D2','A1','AT'};
    old_vals = {Matrix.n Matrix.tau Matrix.D1 Matrix.D2 Matrix.A1 Matrix.AT};
    for i=1:6
        def{i,1} = num2str(old_vals{i},'%11.6g');
    end
    I = inputdlg(names,'Cross WLF parameters',1,def);
    if ~isempty(I)   
        [succes,new_vals]   = convert_input_2_number(names,I);
        new_vals = swap_vals_when_succesful(succes,new_vals,old_vals);
        Matrix.n   = new_vals{1};
        Matrix.tau = new_vals{2};
        Matrix.D1  = new_vals{3};
        Matrix.D2  = new_vals{4};
        Matrix.A1  = new_vals{5};
        Matrix.AT  = new_vals{6};
        setappdata(handles.figure_main,'Matrix',Matrix);
    end
elseif strcmpi(Matrix.Model,'constant')
    names = {'eta'};
    old_vals = {Matrix.eta};
    defs = {num2str(old_vals{1},'%11.6g')};
    I = inputdlg(names,'constant viscosity parameters',1,defs);
     if ~isempty(I)
         [succes, new_vals]   = convert_input_2_number(names,I);
         new_vals = swap_vals_when_succesful(succes,new_vals,old_vals);
         Matrix.eta   = new_vals{1};
         setappdata(handles.figure_main,'Matrix',Matrix);
     end
end
update_parameter_panel(handles);

function [succes, values] = convert_input_2_number(name,I)
nSucces = 0;
for i =1:length(name)
    if strcmpi(I{i},'')
        number = 0.0;
    else
        try
            number = str2num(I{i});
        end
    end
    values{i} = number;
    if (isnumeric(number) && ~isempty(number))
        succes{i} = true;
        nSucces = nSucces+1;
    else
        succes{i} = false;
    end
end
if nSucces<length(I)
    str = [];
    first = true;
    for i=1:length(I)
        if (succes{i} == false)
            if first
                str   = name{i};
                first = false;
            else
                str = [str,', ',name{i}];
            end
        end
    end
    errordlg(['Could not convert ',str,' to a number']);
end

function [new_values] = swap_vals_when_succesful(succes,new_values,old_values)
for i=1:length(succes)
    if succes{i}==false
        new_values{i}=old_values{i};
    end
end

function update_parameter_panel(handles)
Matrix = getappdata(handles.figure_main,'Matrix');
if strcmpi(Matrix.Model,'CrossWLF')
    set(handles.edit_CWLF_n,'String',num2str(Matrix.n));
    set(handles.edit_CWLF_tau,'String',num2str(Matrix.tau));
    set(handles.edit_CWLF_D1,'String',num2str(Matrix.D1,'%11.5g'));
    set(handles.edit_CWLF_D2,'String',num2str(Matrix.D2));
    set(handles.edit_CWLF_A1,'String',num2str(Matrix.A1));
    set(handles.edit_CWLF_AT,'String',num2str(Matrix.AT));
elseif strcmpi(Matrix.Model,'constant')
    set(handles.edit_cvisc_eta,'String',num2str(Matrix.eta));
end


% --- Executes on selection change in popupmenu_selectMat.
function popupmenu_selectMat_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_selectMat (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu_selectMat contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu_selectMat


% --- Executes during object creation, after setting all properties.
function popupmenu_selectMat_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_selectMat (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton_database.
function pushbutton_database_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_database (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
pos_panel = get(handles.uipanel_matrix,'position');
pos_db    = get(handles.uipanel_backpanel_database,'position');
pos_db(1) = 50;
pos_db(2) = pos_panel(4)-20;
set(handles.uipanel_backpanel_database,'position',pos_db);
set(handles.uipanel_backpanel_database,'Visible','on');
Mat = read_Mat_DB;
Str = cellstr('choose material');
for i=1:length(Mat)
    Str{i+1,1}=Mat{i}.Name;
end
set(handles.popupmenu_selectMat,'String',Str);
set(handles.popupmenu_selectMat,'Value',1);
setappdata(handles.figure_main,'database_type','material');

% --- Executes on button press in pushbutton_select_mat_dbase.
function pushbutton_select_mat_dbase_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_select_mat_dbase (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.uipanel_backpanel_database,'Visible','off');
nr = get(handles.popupmenu_selectMat,'Value')-1;
db_type = getappdata(handles.figure_main,'database_type');
if nr>0
    if strcmpi(db_type,'material')
        Mat = read_Mat_DB;
        setappdata(handles.figure_main,'Matrix',Mat{nr});
        set_uipanel_model(handles);
        update_parameter_panel(handles);
    elseif strcmpi(db_type,'weave')
        Weave = read_Weave_DB;
        setappdata(handles.figure_main,'Weave',Weave{nr});
        set_uipanel_weavegeo(handles);
        cla(handles.axes_warpcontours);
        cla(handles.axes_weftcontours);
        set_index_popupmenu_weave_type(handles.popupmenu_weaveselect,Weave{nr}.type);
        popupmenu_weaveselect_Callback(handles.popupmenu_weaveselect, eventdata, handles);
    end
end

function set_index_popupmenu_weave_type(handle,WeaveType)
indx = 1;
switch WeaveType
    case 'plain' 
        indx = 1;
    case '22twill'
        indx = 2;
    case '31twill'
        indx = 3;
    case '5hs'
        indx = 4;
    case '8hs'
        indx = 5;
end
set(handle,'Value',indx)

function edit_CWLF_n_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_n as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_n as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_n_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

function edit_CWLF_tau_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_tau (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_tau as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_tau as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_tau_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_tau (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_CWLF_D1_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_D1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_D1 as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_D1 as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_D1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_D1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_CWLF_D2_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_D2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_D2 as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_D2 as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_D2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_D2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_CWLF_A1_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_A1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_A1 as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_A1 as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_A1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_A1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_CWLF_AT_Callback(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_AT (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_CWLF_AT as text
%        str2double(get(hObject,'String')) returns contents of edit_CWLF_AT as a double


% --- Executes during object creation, after setting all properties.
function edit_CWLF_AT_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_CWLF_AT (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes during object creation, after setting all properties.
function figure_main_CreateFcn(hObject, eventdata, handles)
% hObject    handle to figure_main (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function popupmenu_database_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_database (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes on button press in pushbutton_cancel_db.
function pushbutton_cancel_db_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_cancel_db (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.uipanel_backpanel_database,'Visible','off');



% --- Executes on key press with focus on popupmenu_selectMat and none of its controls.
function popupmenu_selectMat_KeyPressFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_selectMat (see GCBO)
% eventdata  structure with the following fields (see UICONTROL)
%	Key: name of the key that was pressed, in lower case
%	Character: character interpretation of the key(s) that was pressed
%	Modifier: name(s) of the modifier key(s) (i.e., control, shift) pressed
% handles    structure with handles and user data (see GUIDATA)




% --- Executes on button press in pushbutton9.
function pushbutton9_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in pushbutton_selectmatrixtab.
function pushbutton_selectmatrixtab_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_selectmatrixtab (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
setappdata(handles.figure_main,'active_panel',1)
show_visible_panel( handles);

% --- Executes on button press in pushbutton_selectgeotab.
function pushbutton_selectgeotab_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_selectgeotab (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
setappdata(handles.figure_main,'active_panel',2);
show_visible_panel( handles);

% --- Executes on button press in pushbutton_selectfrictiontab.
function pushbutton_selectfrictiontab_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_selectfrictiontab (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
setappdata(handles.figure_main,'active_panel',3);
show_visible_panel( handles);

% --- Executes when uipanel_matrix is resized.
function uipanel_matrix_ResizeFcn(hObject, eventdata, handles)
% hObject    handle to uipanel_matrix (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
position = get(hObject,'position');
% min_x = 100;
% min_y = 35;
% if position(3)<min_x
%     position(3)=min_x;
% end    
% if position(4)<min_y
%     position(4)=min_y;
% end    
% set(hObject,'position',position);

% resize the panels and the plot area
width_left_side  = 33;
hight_model      = 17.5;
hight_plot       = 11;
gap              = 0.1; 
space_around_plot_x = 13;
space_around_plot_y = 3.5;

width_right_side = position(3)-width_left_side;
pos_model    = [ gap  position(4)-hight_model-gap   width_left_side-2*gap hight_model-2*gap ];
pos_plot     = [ gap  pos_model(2)-hight_plot-gap       width_left_side-2*gap hight_plot-2*gap ];
pos_axes     = [ width_left_side+space_around_plot_x  space_around_plot_y...
                 width_right_side-1.25*space_around_plot_x   position(4)-1.5*space_around_plot_y];
             
%set(handles.uipanel_database,'position',pos_database);
set(handles.uipanel_model,'Position',pos_model);
set(handles.uipanel_plot,'Position',pos_plot);
set(handles.axes_plot,'Position',pos_axes);

function show_visible_panel( handles)
active_panel = getappdata(handles.figure_main,'active_panel');
set(handles.uipanel_matrix,'Visible','off');
set(handles.uipanel_weavegeo,'Visible','off');
set(handles.uipanel_fricprop,'Visible','off');
switch active_panel
    case 1
        set(handles.uipanel_matrix,'Visible','on');
    case 2        
        set(handles.uipanel_weavegeo,'Visible','on');
    case 3        
        set(handles.uipanel_fricprop,'Visible','on');
    otherwise
        set(handles.uipanel_matrix,'Visible','on');
end
        


% --- Executes on selection change in popupmenu_weaveselect.
function popupmenu_weaveselect_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_weaveselect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu_weaveselect contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu_weaveselect
contents = get(hObject,'String');
selected_weave_type = contents{get(hObject,'Value')};
switch selected_weave_type
    case 'plain weave'
        WeaveType = 'plain';
        im = imread('./figures/plain.jpg');        
    case 'twill 2/2'
        WeaveType = '22twill';
        im = imread('./figures/22twill.jpg');        
    case 'twill 3/1'
        WeaveType = '31twill';
        im = imread('./figures/31twill.jpg');        
    case '5H satin'
        WeaveType = '5hs';
        im = imread('./figures/5HS.jpg');        
    case '8H satin'
        WeaveType = '8hs';
        im = imread('./figures/8HS.jpg');
end
Weave = getappdata(handles.figure_main,'Weave');
Weave.type = WeaveType;
setappdata(handles.figure_main,'Weave',Weave);

% clear the plots
cla(handles.axes_weave);
cla(handles.axes_warpcontours);
cla(handles.axes_weftcontours);

% plot weave
H = handles.axes_weave;
imshow(im,'Parent',H);
hold on;
s = size(im);
text(0,s(1)+20,'warp','Parent',H);
text(s(2),s(1)+20,'weft','Parent',H);

% --- Executes during object creation, after setting all properties.
function popupmenu_weaveselect_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_weaveselect (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_warpcount_Callback(hObject, eventdata, handles)
% hObject    handle to edit_warpcount (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_warpcount as text
%        str2double(get(hObject,'String')) returns contents of edit_warpcount as a double


% --- Executes during object creation, after setting all properties.
function edit_warpcount_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_warpcount (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_weftcount_Callback(hObject, eventdata, handles)
% hObject    handle to edit_weftcount (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_weftcount as text
%        str2double(get(hObject,'String')) returns contents of edit_weftcount as a double


% --- Executes during object creation, after setting all properties.
function edit_weftcount_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_weftcount (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_spacing_Callback(hObject, eventdata, handles)
% hObject    handle to edit_spacing (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_spacing as text
%        str2double(get(hObject,'String')) returns contents of edit_spacing as a double


% --- Executes during object creation, after setting all properties.
function edit_spacing_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_spacing (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on slider movement.
function slider_geo_Callback(hObject, eventdata, handles)
% hObject    handle to slider_geo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
Weave = getappdata(handles.figure_main,'Weave');
npoints = get(hObject,'Value');
Weave.npoints = ceil(npoints);
setappdata(handles.figure_main,'Weave',Weave);
set_uipanel_weavegeo(handles);

% --- Executes during object creation, after setting all properties.
function slider_geo_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider_geo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end



function edit_thickness_Callback(hObject, eventdata, handles)
% hObject    handle to edit_thickness (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_thickness as text
%        str2double(get(hObject,'String')) returns contents of edit_thickness as a double


% --- Executes during object creation, after setting all properties.
function edit_thickness_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_thickness (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton20.
function pushbutton20_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton20 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes when uipanel_weavegeo is resized.
function uipanel_weavegeo_ResizeFcn(hObject, eventdata, handles)
% hObject    handle to uipanel_weavegeo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
pos = get(hObject,'position');
pos_uipanel_selectweave = get(handles.uipanel_selectweave,'position');

% resize the panels and the plot area
width_left_side  = 33;
hight_weave      = pos_uipanel_selectweave(4);
gap              = 0.1; 
space_around_plot_x = 13;
space_around_plot_y = 3.5;

width_right_side = pos(3)-width_left_side;
hight_plot       = pos(4)/3;
pos_weave    = [ gap  pos(4)-hight_weave-3*gap   width_left_side-2*gap hight_weave ];
pos_axes_weftc  = [ width_left_side+space_around_plot_x         space_around_plot_y...
                    width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];
pos_axes_warpc  = [ pos_axes_weftc(1)                           pos_axes_weftc(2) + hight_plot...
                    width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];
pos_axes_weave  = [ pos_axes_weftc(1)                           pos_axes_warpc(2)+hight_plot...
                    width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];
                
%set(handles.uipanel_database,'position',pos_database);
set(handles.uipanel_selectweave,'Position',pos_weave);
set(handles.axes_weave,'Position',pos_axes_weave);
set(handles.axes_warpcontours,'Position',pos_axes_warpc);
set(handles.axes_weftcontours,'Position',pos_axes_weftc);

% --- Executes on button press in pushbutton_adjustgeo.
function pushbutton_adjustgeo_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_adjustgeo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
names = {'warp count [-/m]','weft count [-/m]','spacing [%]','thickness [mm]'};
Weave = getappdata(handles.figure_main,'Weave');
old_vals{1} = Weave.warpcount;
old_vals{2} = Weave.weftcount;
old_vals{3} = Weave.spacing;
old_vals{4} = Weave.thickness;
for i=1:4
    def{i,1} = num2str(old_vals{i},'%11.6g');
end
I = inputdlg(names,'Weave properties',1,def);
if ~isempty(I)   
    [succes,new_vals]   = convert_input_2_number(names,I);
    new_vals = swap_vals_when_succesful(succes,new_vals,old_vals);
    if new_vals{1}<=0
        errordlg('Warp count must be larger than 0')
        uiwait;
    else
        Weave.warpcount = new_vals{1};
    end
    if new_vals{2}<=0
        errordlg('Weft count must be larger than 0')
        uiwait;
    else
        Weave.weftcount = new_vals{2};
    end
    if new_vals{3}<0 || new_vals{3}>90
        errordlg('Spacing percentage must be between 0 and 90%')
        uiwait;
    else
        Weave.spacing   = new_vals{3};
    end
     if new_vals{4}<=0
        errordlg('Thickness must be larger than 0')
        uiwait;
     else
         Weave.thickness = new_vals{4};
     end
    setappdata(handles.figure_main,'Weave',Weave);
end
set_uipanel_weavegeo(handles);
cla(handles.axes_warpcontours);
cla(handles.axes_weftcontours);


% --- Executes on button press in pushbutton_plotgeo.
function pushbutton_plotgeo_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_plotgeo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Weave = getappdata(handles.figure_main,'Weave');
[Geo] = create_geometry( Weave.type, 'top', Weave.warpcount/1000, Weave.weftcount/1000,...
                         Weave.spacing, Weave.thickness, Weave.npoints);
H = handles.axes_warpcontours;
plot_contours_in_fig(H,Geo,Weave);
title(H,'slip in the warp direction/top surface or weft direction/lower surface','FontWeight','bold')

[Geo] = create_geometry( Weave.type, 'bottom', Weave.warpcount/1000, Weave.weftcount/1000,...
                         Weave.spacing, Weave.thickness, Weave.npoints);
H = handles.axes_weftcontours;
plot_contours_in_fig(H,Geo,Weave);
title(H,'slip in the weft direction/top surface or warp direction/lower surface','FontWeight','bold')

% function plot_contours_in_fig(H,Geo,Weave)
% colspec  = {'k' 'r' 'b' 'g' 'c' 'm' 'y'};
% cla(H)
% hold(H,'on')
% minC = 1e99;
% maxC = 1e-99;
% top = Weave.thickness/4;
% iline = 0;
% for ic = 1:Geo.nGeo
%     plot(H,Geo.Contour{ic}.x,Geo.Contour{ic}.y,colspec{ic})
%     
%     % print info
%     iline = iline + 1;
%     text(0,top-iline*top/10,['nr. of contours : ',num2str(Geo.nCont{ic})],'Parent',H,'Color',colspec{ic});
%     iline = iline + 1;    
%     text(0,top-iline*top/10,['contour width   : ',num2str(Geo.Width{ic}),' mm'],'Parent',H,'Color',colspec{ic});
%    
%     % keep track of min and max
%     minCi = min(Geo.Contour{ic}.x);
%     maxCi = max(Geo.Contour{ic}.x);
%     if minCi<minC
%         minC = minCi;
%     end
%     if maxCi>maxC
%         maxC = maxCi;
%     end
% end
% iline = iline + 1;  
% text(0,top-iline*top/10,['unit cell area   : ',num2str(Geo.UCellArea),' mm2'],'Parent',H,'FontAngle','italic');
% iline = iline + 1;
% text(0,top-iline*top/10,['nr. pnts. discr. : ',num2str(Geo.Contour{Geo.nGeo}.n)],'Parent',H,'FontAngle','italic');
% 
% ax = axis(H);
% ax(2) = 1.01*maxC;
% ax(1) = minC-0.01*(maxC-minC);
% ax(3) = 0;
% ax(4) = Weave.thickness/4;
% axis(H,ax);
% set(H,'DataAspectRatioMode','auto')
% %set(H,'DataAspectRatio',[1 1 1])
% xlabel(H,'position x [mm]');
% ylabel(H,'position z [mm]');

function plot_contours_in_fig(H,Geo,Weave)
%colspec  = {'k' 'r' 'b' 'g' 'c' 'm' 'y'};
cla(H)
hold(H,'on')
minC = 1e99;
maxC = 1e-99;
top = Weave.thickness/4;
x0 = 0;
for ic = 1:Geo.nGeo
    width_geo = 100/(100-Weave.spacing)*(Geo.Contour{ic}.x(end)-Geo.Contour{ic}.x(1));
    x0 = x0 + width_geo/2;
    plot(H, x0 + Geo.Contour{ic}.x,Geo.Contour{ic}.y,'k')
    fill(x0 + Geo.Contour{ic}.x,Geo.Contour{ic}.y,[0.9 0.92 0.95],'Parent',H);

    % print info
    iline = 1;
    text(x0,top-iline*top/7,['n: ',num2str(Geo.nCont{ic})],...
         'Parent',H,'FontName','arial','HorizontalAlignment','center','FontSize',8,'BackgroundColor',[1 1 1]);
    iline = iline + 1;    
    text(x0,top-iline*top/7,['d: ',num2str(Geo.Width{ic}),' mm'],...
        'Parent',H,'FontName','arial','HorizontalAlignment','center','FontSize',8,'BackgroundColor',[1 1 1]);

    % update x0
    x0 = x0 + width_geo/2;

    % keep track of min and max
%     minCi = min(Geo.Contour{ic}.x);
%     maxCi = max(Geo.Contour{ic}.x);
%     if minCi<minC
%         minC = minCi;
%     end
%     if maxCi>maxC
%         maxC = maxCi;
%     end
end

ax = axis(H);
ax(2) = 1.01*x0;
ax(1) = -0.01*x0;
ax(3) = 0-0.5*top;
ax(4) = top;

% plot the unit cell boundaries
plot(H,ax(1:2),[0 0],'k:')
plot(H,[0 0],[ax(3) top],'k:')
plot(H,[x0 x0],[ax(3) top],'k:')

% plot the tool
fill( ax([1,2,2,1]), [ax(3) ax(3) -0.2*top  -0.2*top],0.9*ones(1,3),'Parent',H);
text(ax(2)/2, -top/8, 'variable film thickness h_0',...
   'Parent',H,'FontName','arial','HorizontalAlignment','center','FontSize',8);
text(ax(2)/2, -top/3, 'tool',...
   'Parent',H,'FontName','arial','HorizontalAlignment','center','FontSize',8);

% % put some info on the unit cell on screen
iline = iline + 3;
text(ax(2)/2,top-iline*top/8,['unit cell area: ',num2str(Geo.UCellArea),' mm2'],'Parent',H,...
    'FontName','arial','HorizontalAlignment','center','FontSize',8,'FontWeight','bold','BackgroundColor',[1 1 1]);
iline = iline + 1.1;
text(ax(2)/2,top-iline*top/8,['nr. pnts. discr.: ',num2str(Geo.Contour{Geo.nGeo}.n)],'Parent',H,...
    'FontName','arial','HorizontalAlignment','center','FontSize',8,'FontWeight','bold','BackgroundColor',[1 1 1]);

axis(H,ax);
set(H,'DataAspectRatioMode','auto')
%set(H,'DataAspectRatio',[1 1 1])
xlabel(H,'position in unit cell [mm]');
ylabel(H,'position z [mm]');


function set_uipanel_weavegeo(handles)
Weave = getappdata(handles.figure_main,'Weave');
set(handles.edit_warpcount,'string',num2str(Weave.warpcount));
set(handles.edit_weftcount,'string',num2str(Weave.weftcount));
set(handles.edit_spacing,'string',num2str(Weave.spacing));
set(handles.edit_thickness,'string',num2str(Weave.thickness));
set(handles.slider_geo,'value',Weave.npoints);


% --- Executes on button press in pushbutton_clear_fricprop.
function pushbutton_clear_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_clear_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
button = questdlg('Clear graph?','Clear graph','last','all','cancel','cancel');
H1 = handles.axes_stribeck;
H2 = handles.axes_hfilm;
H3 = handles.axes_tau;
Exp2Workspace = getappdata(handles.figure_main,'Exp2Workspace');
if strcmpi(button,'all')
    cla(H1);
    cla(H2);
    cla(H3);
    legend(H1,'off');
    legend(H2,'off');
    legend(H3,'off');
    % clear exported data as well
    Exp2Workspace = [];
elseif strcmpi(button,'last')
    HV = [H1,H2,H3];
    for i=1:3
        H = HV(i);
        Hch = get(H,'Children');
        if ~isempty(Hch)
            Hlast = Hch(1);
            delete(Hlast);
            lHandle = legend(H);
            Leg = get(lHandle,'String');
            Leg = Leg(1:end-1);
            if ~isempty(Leg)
                legend(H,Leg,'FontSize',7);
            else
                legend(H,'off');
            end
        end
    end
    % clear exported data as well
    NewExp2Workspace=[];
    for i=1:length(Exp2Workspace)-1
        NewExp2Workspace{i} = Exp2Workspace{i};
    end
    Exp2Workspace = NewExp2Workspace;
end
setappdata(handles.figure_main,'Exp2Workspace',Exp2Workspace);


% --- Executes on button press in pushbutton_plot_fricprop.
function pushbutton_plot_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_plot_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% calculate frictional properties and plot graphs
FricProp = getappdata(handles.figure_main,'FricProp');

% weave properties
Weave = getappdata(handles.figure_main,'Weave');
[Geo] = create_geometry( Weave.type, FricProp.dir , Weave.warpcount, Weave.weftcount,...
                         Weave.spacing, Weave.thickness/1000, Weave.npoints);

% matrix material
Matrix = getappdata(handles.figure_main,'Matrix');
vel_vector = logspace(log10(FricProp.vmin),log10(FricProp.vmax),FricProp.n);
pressure   = FricProp.p*1000;
Par.N_Goal = pressure*(Geo.UCellArea);
Par.T      = FricProp.T;        % degrees C
Par.MaxNrm = 1.0e-10;
Par.MaxIter= 25;
Par.h_min  = 1e-12;
Par.h0     = 50e-6;  % initial guess
% upper and lower limit
if FricProp.use_lower_limit
    Par.lowlimit = FricProp.lower_limit*1e-6;
else
    Par.lowlimit = 0.0;
end

if FricProp.use_upper_limit
    Par.uplimit = FricProp.upper_limit;
else
    Par.uplimit = 1.0e99;
end

for iv = 1:FricProp.n
    
    Par.v  = vel_vector(iv)*1e-3; % velocity
    
    Par = solveREGeo(Matrix,Geo,Par);

    disp(' ')
    disp('Unit cell values:')
    disp(['  Temperature:    ',num2str(Par.T),' C'])
    disp(['  Velocity:       ',num2str(Par.v),' mm/s'])
    disp(['  Normal force:   ',num2str(Par.N),' N'])
    disp(['  Friction force: ',num2str(Par.Ff),' N'])
    disp(['  mu:             ',num2str(Par.Ff/Par.N),' N/N'])
    disp(' ')
 
    h0_vector(iv)= Par.h0;
    mu_vector(iv)= Par.Ff/Par.N;
    tau_vector(iv)= Par.Ff/Geo.UCellArea;
end

% create the legend string
matrixname =[Matrix.Name,', ',Matrix.Model];
sldir = ' ';
if strcmpi(FricProp.dir,'top')
    sldir = 'warp/top-weft/bottom';
elseif strcmpi(FricProp.dir,'bottom')
    sldir = 'warp/bottom-weft/top';
end
leg = cellstr([Weave.type,', ',sldir,', ',matrixname,', T: ',num2str(Par.T),' C, pn: ',num2str(pressure/1000),' kPa']);

% plot
H = handles.axes_stribeck;
plot_stribeck(H,vel_vector,mu_vector,leg);
datacursormode on;
H = handles.axes_hfilm;
plot_hfilm(H,vel_vector,h0_vector,leg);
datacursormode on;
H = handles.axes_tau;
plot_tau(H,vel_vector,tau_vector,leg);
datacursormode on;

% save the stuf to be able to export it to the workspace
Exp2Workspace = getappdata(handles.figure_main,'Exp2Workspace');
nCurves = length(Exp2Workspace);
icurve = nCurves+1;
Exp2Workspace{icurve}.Temp     =  Par.T;
Exp2Workspace{icurve}.pressure =  Par.N/Geo.UCellArea;
Exp2Workspace{icurve}.velocity =  vel_vector;
Exp2Workspace{icurve}.tau      =  tau_vector;
Exp2Workspace{icurve}.fric     =  mu_vector;
Exp2Workspace{icurve}.filmthk  =  h0_vector;
Exp2Workspace{icurve}.name     =  leg{1};
setappdata(handles.figure_main,'Exp2Workspace',Exp2Workspace);

function plot_stribeck(H,vel,mu,lg)
line_spec = determine_linespecs(H);
semilogx(H,vel,mu,line_spec)
hold(H,'on');
xlabel(H,'slip velocity [mm/s]')
ylabel(H,'friction coefficient [N/N]')
title(H,'Friction coefficient','FontWeight','bold')
Leg = get(legend(H),'String');
Leg = [Leg, cellstr(lg)];
legend(H,Leg,'Location','NorthWest','FontSize',7);
axis(H,'auto');
ax = axis(H);
ax(1)=10^floor(log10(ax(1)));
ax(2)=10^ceil(log10(ax(2)));
ax(3) = 0;
axis(H,ax);

function plot_hfilm(H,vel,h,lg)
line_spec = determine_linespecs(H);
semilogx(H,vel,h*1e6,line_spec)
hold(H,'on');
xlabel(H,'slip velocity [mm/s]');
ylabel(H,'film thickness  [\mum]');
title(H,'Film thickness in microns','FontWeight','bold');
Leg = get(legend(H),'String');
Leg = [Leg, cellstr(lg)];
legend(H,Leg,'Location','NorthWest','FontSize',7);
axis(H,'auto');
ax = axis(H);
ax(1)=10^floor(log10(ax(1)));
ax(2)=10^ceil(log10(ax(2)));
ax(3) = 0;
axis(H,ax);
% plot the 10 micron lower limit for the model
%plot(H,ax(1:2),[10 10],'r');

function plot_tau(H,vel,tau,lg)
line_spec = determine_linespecs(H);
semilogx(H,vel,1e-3*tau,line_spec)
hold(H,'on');
xlabel(H,'slip velocity [mm/s]');
ylabel(H,'apparent  \tau [kPa]');
title(H,'Average interface traction','FontWeight','bold');
Leg = get(legend(H),'String');
Leg = [Leg, cellstr(lg)];
legend(H,Leg,'Location','NorthWest','FontSize',7);
axis(H,'auto');
ax = axis(H);
ax(1)=10^floor(log10(ax(1)));
ax(2)=10^ceil(log10(ax(2)));
ax(3) = 0;
axis(H,ax);

% determine linespecs
function [spec] = determine_linespecs(H)
nplots = length(get(H,'Children'))+1;
linespec = {'-' '--' ':' '-.'};
colspec  = {'k' 'r' 'b' 'g' 'c' 'm' 'y'};
ilspec = 1;
icspec = 1;
for i=1:nplots
    if ilspec>length(linespec)
        ilspec = 1;
        icspec = icspec + 1;
    end
    if icspec>length(colspec)
        icspec = 1;
    end
    spec = [colspec{icspec},linespec{ilspec}];
    ilspec = ilspec + 1;
end

function edit_T_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_T_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_T_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_T_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.T = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);

% --- Executes during object creation, after setting all properties.
function edit_T_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_T_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_vmax_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_vmax_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_vmax_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_vmax_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.vmax = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);

% --- Executes during object creation, after setting all properties.
function edit_vmax_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_vmax_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_vmin_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_vmin_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_vmin_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_vmin_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.vmin = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);

% --- Executes during object creation, after setting all properties.
function edit_vmin_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_vmin_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_p_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_p_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_p_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_p_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.p = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);

% --- Executes during object creation, after setting all properties.
function edit_p_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_p_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function edit_n_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_n_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_n_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_n_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.n = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);

% --- Executes during object creation, after setting all properties.
function edit_n_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_n_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes when uipanel_fricprop is resized.
function uipanel_fricprop_ResizeFcn(hObject, eventdata, handles)
% hObject    handle to uipanel_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
pos = get(hObject,'position');
pos_uipanel_fricprop_par = get(handles.uipanel_fricprop_par,'position');

% resize the panels and the plot area
width_left_side  = 33;
hight_frprop_par = pos_uipanel_fricprop_par(4);
gap              = 0.1; 
space_around_plot_x = 13;
space_around_plot_y = 4;

width_right_side = pos(3)-width_left_side;
hight_plot       = pos(4)/3;
pos_frprop_par     = [ gap  pos(4)-hight_frprop_par-3*gap   width_left_side-2*gap hight_frprop_par ];
pos_axes_hfilm      = [width_left_side+space_around_plot_x         space_around_plot_y...
                       width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];
pos_axes_stribeck  = [ pos_axes_hfilm(1)                           pos_axes_hfilm(2) + hight_plot...
                       width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];
pos_axes_tau       = [ pos_axes_stribeck(1)                           pos_axes_stribeck(2) + hight_plot...
                       width_right_side-1.25*space_around_plot_x   hight_plot-1.5*space_around_plot_y];                   

set(handles.uipanel_fricprop_par,'Position',pos_frprop_par);
set(handles.axes_stribeck,'Position',pos_axes_stribeck);
set(handles.axes_hfilm,'Position',pos_axes_hfilm);
set(handles.axes_tau,'Position',pos_axes_tau);

function set_uipanel_fricprop(handles)
FricProp = getappdata(handles.figure_main,'FricProp');
set(handles.edit_T_fricprop,'string',num2str(FricProp.T));
set(handles.edit_p_fricprop,'string',num2str(FricProp.p));
set(handles.edit_vmin_fricprop,'string',num2str(FricProp.vmin));
set(handles.edit_vmax_fricprop,'string',num2str(FricProp.vmax));
set(handles.edit_n_fricprop,'string',num2str(FricProp.n));
if strcmpi( FricProp.dir,'top')
    set(handles.popupmenu_direction,'Value',1);
elseif strcmpi( FricProp.dir,'bottom')
    set(handles.popupmenu_direction,'Value',2);    
else
    error('unknown slip direction')
end
set(handles.checkbox_lowlimit,'value',FricProp.use_lower_limit);
set(handles.checkbox_uplimit,'value',FricProp.use_upper_limit);
set(handles.edit_lowlim_fricprop,'string',num2str(FricProp.lower_limit));
set(handles.edit_uplim_fricprop,'string',num2str(FricProp.upper_limit));

% --- Executes during object creation, after setting all properties.
function uipanel_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to uipanel_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called




% --- Executes on selection change in popupmenu_direction.
function popupmenu_direction_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu_direction (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu_direction contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu_direction
val = get(hObject,'Value');
FricProp = getappdata(handles.figure_main,'FricProp');
if val == 1
    FricProp.dir = 'top';
elseif val==2
    FricProp.dir = 'bottom';
else
    error('unknown dir in popupmenu_direction_Callback')
end
setappdata(handles.figure_main,'FricProp',FricProp);

% --- Executes during object creation, after setting all properties.
function popupmenu_direction_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_direction (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% --- Executes on button press in pushbutton_weave_db.
function pushbutton_weave_db_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_weave_db (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
pos_panel = get(handles.uipanel_matrix,'position');
pos_db    = get(handles.uipanel_backpanel_database,'position');
pos_db(1) = 50;
pos_db(2) = pos_panel(4)-20;
set(handles.uipanel_backpanel_database,'position',pos_db);
set(handles.uipanel_backpanel_database,'Visible','on');
Weave = read_Weave_DB;
Str = cellstr('choose weave');
for i=1:length(Weave)
    Str{i+1,1}=Weave{i}.Name;
end
set(handles.popupmenu_selectMat,'String',Str);
set(handles.popupmenu_selectMat,'Value',1);
setappdata(handles.figure_main,'database_type','weave');

% --- Executes on button press in pushbutton_export.
function pushbutton_export_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton_export (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
Exp2Workspace = getappdata(handles.figure_main,'Exp2Workspace');
names = {'none available'};
if isempty(Exp2Workspace)
    warndlg('Nothing to export');
    return;
end
for i=1:length(Exp2Workspace)
    names{i}=Exp2Workspace{i}.name;
end
[sel,ok] = listdlg('PromptString','Select curve to export to workspace:',...
                'SelectionMode','single',...
                'ListString',names,...
                'ListSize',[350 200]);
if ~ok
    return
end
checkLabels = {'Save name'...
               'Save temperature'...
               'Save pressure'...
               'Save velocity'...
               'Save shear stress:'...
               'Save coeff. of friction:'...
               'Save film thickness'}; 
varNames = {'name','Temp','pressure','velocity','tau','fric','filmthk'};
icurve = sel;
items = { Exp2Workspace{icurve}.name,...
          Exp2Workspace{icurve}.Temp,...
          Exp2Workspace{icurve}.pressure,... 
          Exp2Workspace{icurve}.velocity,...          
          Exp2Workspace{icurve}.tau,...
          Exp2Workspace{icurve}.fric,...
          Exp2Workspace{icurve}.filmthk};
export2wsdlg(checkLabels,varNames,items,...
             'Export to Workspace')

function edit_lowlim_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_lowlim_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_lowlim_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_lowlim_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.lower_limit = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);


% --- Executes during object creation, after setting all properties.
function edit_lowlim_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_lowlim_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit_uplim_fricprop_Callback(hObject, eventdata, handles)
% hObject    handle to edit_uplim_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit_uplim_fricprop as text
%        str2double(get(hObject,'String')) returns contents of edit_uplim_fricprop as a double
nmbr = [];
try
    nmbr = str2double(get(hObject,'String'));
end
if (isnumeric(nmbr) && ~isnan(nmbr))
    % if it is a number
    FricProp = getappdata(handles.figure_main,'FricProp');
    FricProp.upper_limit = nmbr;
    setappdata(handles.figure_main,'FricProp',FricProp);
else
    errordlg('Cannot convert input to a numeric value')
end
set_uipanel_fricprop(handles);


% --- Executes during object creation, after setting all properties.
function edit_uplim_fricprop_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit_uplim_fricprop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox_lowlimit.
function checkbox_lowlimit_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_lowlimit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkbox_lowlimit
val = get(hObject,'Value');
FricProp = getappdata(handles.figure_main,'FricProp');
FricProp.use_lower_limit = val;
setappdata(handles.figure_main,'FricProp',FricProp);
set_uipanel_fricprop(handles);

% --- Executes on button press in checkbox_uplimit.
function checkbox_uplimit_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox_uplimit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkbox_uplimit
val = get(hObject,'Value');
FricProp = getappdata(handles.figure_main,'FricProp');
FricProp.use_upper_limit = val;
setappdata(handles.figure_main,'FricProp',FricProp);
set_uipanel_fricprop(handles);


function edit43_Callback(hObject, eventdata, handles)
% hObject    handle to edit43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit43 as text
%        str2double(get(hObject,'String')) returns contents of edit43 as a double


% --- Executes during object creation, after setting all properties.
function edit43_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit44_Callback(hObject, eventdata, handles)
% hObject    handle to edit44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit44 as text
%        str2double(get(hObject,'String')) returns contents of edit44 as a double


% --- Executes during object creation, after setting all properties.
function edit44_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit45_Callback(hObject, eventdata, handles)
% hObject    handle to edit45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit45 as text
%        str2double(get(hObject,'String')) returns contents of edit45 as a double


% --- Executes during object creation, after setting all properties.
function edit45_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit46_Callback(hObject, eventdata, handles)
% hObject    handle to edit46 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit46 as text
%        str2double(get(hObject,'String')) returns contents of edit46 as a double


% --- Executes during object creation, after setting all properties.
function edit46_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit46 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit47_Callback(hObject, eventdata, handles)
% hObject    handle to edit47 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit47 as text
%        str2double(get(hObject,'String')) returns contents of edit47 as a double


% --- Executes during object creation, after setting all properties.
function edit47_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit47 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit48_Callback(hObject, eventdata, handles)
% hObject    handle to edit48 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit48 as text
%        str2double(get(hObject,'String')) returns contents of edit48 as a double


% --- Executes during object creation, after setting all properties.
function edit48_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit48 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit49_Callback(hObject, eventdata, handles)
% hObject    handle to edit49 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit49 as text
%        str2double(get(hObject,'String')) returns contents of edit49 as a double


% --- Executes during object creation, after setting all properties.
function edit49_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit49 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end




% --- Executes during object creation, after setting all properties.
function uipanel_model_CreateFcn(hObject, eventdata, handles)
% hObject    handle to uipanel_model (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called





% --------------------------------------------------------------------
function help_Callback(hObject, eventdata, handles)
% hObject    handle to help (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --------------------------------------------------------------------
function u20help_Callback(hObject, eventdata, handles)
% hObject    handle to u20help (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% call the html help file
web ([cd,'/help/u20_friction_tool.htm'])

% --------------------------------------------------------------------
function about_Callback(hObject, eventdata, handles)
% hObject    handle to about (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
msg = cellstr('U20 Friction Tool');
msg{2}=' ';
msg{3} = 'University of Twente';
msg{4} = 'Production Technology group';
msg{5} = 'www.pt.ctw.utwente.nl';
h = msgbox(msg,'About', 'help');


% --- If Enable == 'on', executes on mouse press in 5 pixel border.
% --- Otherwise, executes on mouse press in 5 pixel border or over popupmenu_model.
function popupmenu_model_ButtonDownFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu_model (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


