%*************************************************************************%
%                          U20 Friction Tool                              %
%                                                                         %
% This file is part of the U20 Friction Tool. The U20 Friction tool is    %
% free software. You can use, redistribute and modify it. If you publish  %
% results obtained with this tool (or any tool based on this code),       %
% please cite the following article:                                      %
%                                                                         %
% R.H.W. ten Thije, R. Akkerman, L. van der Meer, M. P. Ubbink,           %
% Tool-ply friction in thermoplastic composite forming,                   %
% International Journal of Material Forming, Volume 1, p. 953-956 (2008)  %
%                                                                         %
% This library is distributed in the hope that it will be useful, but     %
% WITHOUT ANY WARRANTY.                                                   %
%                                                                         %
% Copyright (C) 2009 Rene ten Thije.                                      %
% Developed at the University of Twente, the Netherlands.                 %
% Chair of Production Technology, www.pt.ctw.utwente.nl                   %
% info: r.tenthije@utwente.nl / r.akkerman@utwente.nl                     %
%                                                                         %
%*************************************************************************%

function eta = give_eta(mat,T,gam_dot)

% syntax: eta = eta(mat,T,gam_dot)
% gives the viscosity of the material at temperature T[ deg C] and shear
% rate gam_dot. Gam_dot can be a vector

model = lower(mat.Model);

if strcmpi(model,'crosswlf')
    eta = give_eta_crosswlf(mat,T,gam_dot);
elseif strcmpi(model,'PowLawArrhFit')
    eta = give_eta_pwlafit(mat,T,gam_dot);
elseif strcmpi(model,'constant')
    eta = mat.eta*ones(1,length(gam_dot));
else
    error('Unknown material model');
end